@@ -127,18 +127,33 @@ class NodeSelectionCommandMixin:
 
     Options:
         -g --groups
+
+    Use <group>.<index> or <uuid>.<index> to talk to non-primary elements.
     """
 
     @staticmethod
     def get_addresses(application, arguments):
-        uuids = arguments.get("<uuid>", [])
-        groups = arguments.get("<groups>", [])
-        return [
-            node.address
-            for node in application.network.nodes
-            if node.uuid.hex[:4] in uuids
-            or application.network.get_node_group(node) in groups
-        ]
+        uuids = {}
+        for uuid_element in arguments.get("<uuid>", []):
+            uuid, *element = uuid_element.split(".", maxsplit=1)
+            uuids[uuid] = int(element[0]) if element else 0
+
+        groups = {}
+        for group_element in arguments.get("<groups>", []):
+            group, *element = group_element.split(".", maxsplit=1)
+            groups[group] = int(element[0]) if element else 0
+
+        nodes = []
+        for node in application.network.nodes:
+            offset = uuids.get(node.uuid.hex[:4])
+            if offset is not None:
+                nodes.append(node.address + offset)
+
+            offset = groups.get(application.network.get_node_group(node))
+            if offset is not None:
+                nodes.append(node.address + offset)
+
+        return nodes
 
 
 class LsCommand(Command):
@@ -222,7 +237,7 @@ class AttentionCommand(ModelCommandMixin, Command):
         elif arguments["<groups>"]:
             tasks = [
                 model.attention_unack(
-                    application.network.get_group_address(name, self.MODEL),
+                    application.network.get_group_address(self.MODEL, name=name),
                     app_index=0,
                     attention=attention,
                 )
@@ -269,7 +284,7 @@ class SceneCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
         elif arguments["<groups>"]:
             tasks = [
                 model.recall_scene_unack(
-                    application.network.get_group_address(name, self.MODEL),
+                    application.network.get_group_address(self.MODEL, name=name),
                     app_index=0,
                     scene_number=scene_number,
                     transition_time=transition_time,
@@ -296,7 +311,7 @@ class SceneCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
         method = self.get if arguments["--scene"] is None else self.recall
 
         async for i in method(model, application, arguments):
-            yield i or ''
+            yield i or ""
 
 
 class ModelGetCommandMixin(ModelCommandMixin, NodeSelectionCommandMixin):
@@ -860,7 +875,7 @@ class GenericOnOffCommand(ModelCommandMixin, Command):
             command = getattr(model, "{}_unack".format(self.PARAMETER))
             tasks = [
                 command(
-                    application.network.get_group_address(name, self.MODEL),
+                    application.network.get_group_address(self.MODEL, name=name),
                     app_index=0,
                     onoff=self.TARGET,
                 )
@@ -945,7 +960,7 @@ class MorseCommand(ModelCommandMixin, Command):
         model = self.get_model(application)
 
         destination = application.network.get_group_address(
-            name=arguments["<group>"], model=self.MODEL
+            self.MODEL, name=arguments["<group>"]
         )
 
         send_interval = 0.01
