@@ -330,6 +330,33 @@ class ConfigClient(Model):
         if status["params"]["status"] != StatusCode.SUCCESS:
             raise ModelOperationError("Cannot add net key", status)
 
+        return NetKeyStatus(net_key_index=net_key_index)
+
+    async def delete_net_key(
+        self, destination: int, net_index: int, net_key_index: int
+    ) -> NetKeyStatus:
+        status = self.expect_dev(
+            destination,
+            net_index=net_index,
+            opcode=ConfigOpcode.NETKEY_STATUS,
+            params=dict(net_key_index=net_key_index, status=StatusCode.SUCCESS,),
+        )
+
+        request = partial(
+            self.send_dev,
+            destination,
+            net_index=net_index,
+            opcode=ConfigOpcode.NETKEY_DELETE,
+            params=dict(net_key_index=net_key_index,),
+        )
+
+        status = await self.query(request, status)
+
+        if status["params"]["status"] != StatusCode.SUCCESS:
+            raise ModelOperationError("Cannot delete net key", status)
+
+        return NetKeyStatus(net_key_index=net_key_index)
+
     async def add_app_key(
         self,
         destination: int,
@@ -366,6 +393,33 @@ class ConfigClient(Model):
             status["params"]["net_key_index"], status["params"]["app_key_index"]
         )
 
+    async def delete_app_key(
+        self, destination: int, net_index: int, app_key_index: int, net_key_index: int,
+    ) -> AppKeyStatus:
+        status = self.expect_dev(
+            destination,
+            net_index=net_index,
+            opcode=ConfigOpcode.APPKEY_STATUS,
+            params=dict(net_key_index=net_key_index, app_key_index=app_key_index,),
+        )
+
+        request = partial(
+            self.send_dev,
+            destination,
+            net_index=net_index,
+            opcode=ConfigOpcode.APPKEY_DELETE,
+            params=dict(net_key_index=net_key_index, app_key_index=app_key_index,),
+        )
+
+        status = await self.query(request, status)
+
+        if status["params"]["status"] != StatusCode.SUCCESS:
+            raise ModelOperationError("Cannot delete app key", status)
+
+        return AppKeyStatus(
+            status["params"]["net_key_index"], status["params"]["app_key_index"]
+        )
+
     async def update_app_key(
         self,
         destination: int,
@@ -2052,7 +2106,7 @@ class LightExtendedControllerSetupClient(Model):
         requests = {
             node: partial(
                 self.send_dev,
-                node + 1,
+                node,
                 net_index=net_index,
                 opcode=LightExtendedControllerOpcode.OPCODE,
                 params=dict(
@@ -2065,13 +2119,13 @@ class LightExtendedControllerSetupClient(Model):
 
         statuses = {
             node: self.expect_dev(
-                node + 1,
+                node,
                 net_index=net_index,
                 opcode=LightExtendedControllerOpcode.OPCODE,
                 params=dict(
                     subopcode=LightExtendedControllerSubOpcode.PROPERTY_STATUS,
                     payload=dict(id=property_id),
-                )
+                ),
             )
             for node in nodes
         }
@@ -2098,7 +2152,9 @@ class LightExtendedControllerSetupClient(Model):
         )
 
         return {
-            node: None if isinstance(result, Exception) else result["params"]["payload"]["value"]
+            node: None
+            if isinstance(result, Exception)
+            else result["params"]["payload"]["value"]
             for node, result in results.items()
         }
 
